@@ -2,7 +2,7 @@ import logging
 import sys
 from typing import List
 
-from anscenter.core.logging import InterceptHandler
+from anscenter.app.core.logging import InterceptHandler
 from loguru import logger
 from starlette.config import Config
 from starlette.datastructures import CommaSeparatedStrings, Secret
